News
====

* **29.03.2024** Version 2024.1 released (new constant-in-a-region field
  approximation, new term: passive large deformation fibres with exponential
  elastic response, improved solver status reporting, wedge elements + example,
  multi-node linear combination (boundary) conditions + example, etc.), see
  :ref:`release notes <2023.4-2024.1>`.

* **29.12.2023** Version 2023.4 released (new structural elements (linear
  spring, linear truss), spectral element method (LGL quadrature and nodes with
  Lagrange basis), initial support for meshes with elements of different
  topological dimensions, new examples: 2D and 3D truss bridge, h-refinement
  eigenvalue convergence, beam consisting of hexa and tetra elements, many more
  examples included in gallery, etc.), see :ref:`release notes
  <2023.3-2023.4>`.

* **29.09.2023** Version 2023.3 released (example demonstrating nonlinear
  diffusion and volume forces terms, new sensitivity term, proof-of-concept
  JAX-based auto-differentiable terms (elasticity, mass) + elastodynamics
  parameter identification example, etc.), see :ref:`release notes
  <2023.2-2023.3>`.

* **29.06.2023** Version 2023.2 released (replace numpy.distutils by
  scikit-build (cmake), interface for the PRIMME eigenvalue problem solver, new
  declarative modal analysis example, new terms: nonlinear diffusion and
  nonlinear volume forces, etc.), see :ref:`release notes <2023.1-2023.2>`.

* **29.03.2023** Version 2023.1 released (support meshes with cells of
  different topological dimensions, unified treatment of volume and surface
  integrals, updated elastodynamics solvers, reciprocal mass matrix algorithm,
  seismic load and piezo-elastodynamics examples, use GitHub Actions for CI,
  etc.), see :ref:`release notes <2022.4-2023.1>`.

For historians: see :ref:`archived_news`.
